Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ErrorHandler ¶ added in v0.0.2
func ErrorHandler(log logger) func(context.Context, http.ResponseWriter, error)
ErrorHandler returns a function that writes and logs the given error.
func ListenGracefully ¶
ListenGracefully will start a listener on a specified address and blocks until it receives an interrupt or a sigterm, at which point it will start a graceful shutdown and finally return. You MUST provide a logger, it's the only way to see if there are errors
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.